@@ -1,5 +1,6 @@
 import argparse
 import subprocess
+import sys
 
 from docker_compose_env import compile_env
 
@@ -10,7 +11,11 @@ def main():
     parser.add_argument("docker_compose_args", nargs="*")
 
     args = parser.parse_args()
-    compile_env.run(args.spec_file)
+    try:
+        compile_env.run(args.spec_file)
+    except compile_env.RunTimeError as e:
+        print("Error: %s" % e.reason)
+        sys.exit(1)
 
     subprocess.run(
         ["docker-compose %s" % " ".join(args.docker_compose_args)], shell=True
